module Grants
  class Institution
    def self.grants
      {
          create: {
              name: 'Anlegen',
              scopes: {
                  extern_system_wide: {
                      name: 'Externe Systemweit',
                      detailed_description: '
                      keine Einschränkung für externe Einrichtungen.
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability do
                        ability.can :create, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                        ability.can :create_extern, ::Institution
                      end,
                      teacher: -> ability do
                        ability.can :create, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                        ability.can :create_extern, ::Institution
                      end
                  },
                  organisational_system_wide: {
                      name: 'Verwaltungseinrichtungen Systemweit',
                      detailed_description: '
                      keine Einschränkung für Verwaltungseinrichtungen.
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability,manager do
                        ability.can :create, ::Institution, {
                            institution_type: ::Institution::TYPE_ORGANISATIONAL
                        }
                        ability.can :create_organisational, ::Institution
                      end
                  },
                  organisational_own_institutions: {
                      name: 'Verwaltungseinrichtungen im Verwaltungsbereich',
                      detailed_description: '
                      der Verwalter darf Verwaltungseinrichtungen unterhalb seiner eigenen Einrichtung anlegen.
                      Beim Versuch, eine neue Einrichtung anzulegen, stehen nirgendwo Einrichtungen zur Auswahl, die nicht unterhalb seiner eigenen Einrichtung liegen.
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability,manager do
                        ability.can :create, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                        ability.can :create_organisational, ::Institution
                      end
                  },
                  organisational_root_institutions: {
                      name: 'Wurzeleinrichtungen',
                      detailed_description: '
                      der Verwalter darf Verwaltungseinrichtungen ohne eine übergeordnete Einrichtung anlegen.
                      Beim Versuch, eine neue Einrichtung anzulegen, steht die oberste Hierarchiebene zur Auswahl
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability do
                        ability.can :create, ::Institution, {
                            parent_id: nil, # can create
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                        ability.can :create_organisational, ::Institution
                      end
                  },
                  school_system_wide: {
                      name: 'Schulen Systemweit',
                      detailed_description: '
                       keine Einschränkung für Schulen.
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability,manager do
                        ability.can :create, ::Institution, {
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL]
                        }
                        ability.can :create_school, ::Institution
                      end
                  },
                  school_own_institutions: {
                      name: 'Schulen im Verwaltungsbereich',
                      detailed_description: '
                         der Verwalter darf Schulen unterhalb seiner eigenen Einrichtung anlegen.
                      Beim Versuch, eine neue Schule anzulegen, stehen nirgendwo Einrichtungen zur Auswahl, die nicht unterhalb seiner eigenen Einrichtung liegen.
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability,manager do
                        ability.can :create, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL],
                        }
                        ability.can :create_school, ::Institution
                      end
                  },
              }
          },
          read: {
              name: 'Anzeigen',
              scopes: {
                  extern_system_wide: {
                      name: 'Externe Systemweit',
                      detailed_description: '
                       keine Einschränkung für externe Einrichtungen.
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability do
                        ability.can :read, ::Institution, {
                          institution_type: ::Institution::TYPE_EXTERN
                        }
                      end,
                      teacher: -> ability do
                        ability.can :read, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                      end
                  },
                  organisational_system_wide: {
                      name: 'Verwaltungseinrichtungen Systemweit',
                      detailed_description: '
                       keine Einschränkung für Verwaltungseinrichtungen.
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [],
                      manager: -> ability do
                        ability.can :read, ::Institution, {
                            institution_type: ::Institution::TYPE_ORGANISATIONAL
                        }
                      end,
                      teacher: -> ability do
                        ability.can :read, ::Institution, {
                            institution_type: ::Institution::TYPE_ORGANISATIONAL
                        }
                      end
                  },
                  organisational_own_institution: { # eigene oder direkt übergeordnete
                      name: 'eigene Verwaltungseinrichtung',
                      detailed_description: '
                       ein Lehrer darf alle Verwaltungseinrichtung sehen, die genau eine Ebene über einer der Schulen, in der er arbeitet, liegt.
                       Ein Verwalter darf seine eigene Einrichtung sehen, und alle Verwaltungseinrichtung unterhalb seiner eigenen Einrichtung sehen.
                        alle anderen Verwaltungseinrichtungen dürfen nirgendwo gelistet werden.
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability,manager do
                        ability.can :read, ::Institution,  {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                        ability.can :read, ::Institution,  {
                            id: manager.institution_id,
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                      end,
                      teacher: -> ability,teacher do
                        t_ids = ::Institution.connection.select_values("
                                    SELECT institutions.* FROM institutions
                                      INNER JOIN institutions as child_institutions_institutions
                                        ON child_institutions_institutions.parent_id = institutions.id
                                      INNER JOIN teacher_institution_relations
                                        ON teacher_institution_relations.institution_id = child_institutions_institutions.id
                                    WHERE (teacher_institution_relations.teacher_id = #{teacher.id} and institutions.institution_type ='#{::Institution::TYPE_ORGANISATIONAL}')     "
                        ).map(&:to_i)
                        ability.can :read, ::Institution, { id: t_ids  }
                      end
                  },
                  school_system_wide: {
                      name: 'Schulen Systemweit',
                      detailed_description: '
                       keine Einschränkung für Schulen.
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [],
                      manager: -> ability do
                        ability.can :read, ::Institution, {
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL]
                        }
                      end,
                      teacher: -> ability do
                        ability.can :read, ::Institution, {
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL]
                        }
                      end
                  },
                  school_own_institutions: {
                      name: 'Eigene Schulen',
                      detailed_description: '
                       Verwalter dürfen Schulen unterhalb ihrer eigenen Einrichtung sehen.
                       Lehrer dürfen nur die Schulen sehen, an denen Sie arbeiten.
                        Alle anderen Schulen werden nirgendwo gelistet.
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability,manager do
                        ability.can :read, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL],
                        }
                      end,
                      teacher: -> ability,teacher do
                        ability.can :read, ::Institution, {
                            teacher_institution_relations: {
                                teacher_id: teacher.id
                            },
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL],
                        }
                      end
                  },
              }
          },
          update: {
              name: 'Bearbeiten',
              scopes: {
                  extern_system_wide: {
                      name: 'Externe Systemweit',
                      detailed_description: '
                       keine Einschränkungen für externe Einrichtungen
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability do
                        ability.can :update, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                      end,
                      teacher: -> ability do
                        ability.can :update, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                      end
                  },
                  organisational_system_wide: {
                      name: 'Verwaltungseinrichtungen Systemweit',
                      detailed_description: '
                       keine Einschränkungen für Verwaltungseinrichtungen
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :update, ::Institution, {
                            institution_type: ::Institution::TYPE_ORGANISATIONAL
                        }
                      end
                  },
                  organisational_own_institutions: {
                      name: 'Verwaltungseinrichtungen im Verwaltungsbereich',
                      detailed_description: '
                      der Verwalter darf Verwaltungseinrichtungen unterhalb seiner eigenen Einrichtung bearbeiten.
                      Es dürfen nirgendwo Bearbeiten-Buttons für eine Einrichtung angezeigt werden, die nicht unterhalb der Einrichtung des Verwalters liegen.
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability,manager do
                        ability.can :update, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                      end
                  },
                  organisational_root_institutions: {
                      name: 'Wurzeleinrichtungen',
                      detailed_description: '
                      der Verwalter darf Verwaltungseinrichtungen der obersten Hierarchieebene bearbeiten.
                      Es dürfen nirgendwo Bearbeiten-Buttons für eine andere Einrichtung als eine solche der obersten Hierarchieebene angezeigt werden.
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :update, ::Institution, {
                            parent_id: nil,
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                      end
                  },
                  school_system_wide: {
                      name: 'Schulen Systemweit',
                      detailed_description: '
                       keine Einschränkungen für Schulen
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability,manager do
                        ability.can :update, ::Institution, {
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL]
                        }
                      end
                  },
                  school_own_institutions: {
                      name: 'Schulen im Verwaltungsbereich',
                      detailed_description: '
                      der Verwalter darf Schulen unterhalb seiner eigenen Einrichtung bearbeiten.
                      Es dürfen nirgendwo Bearbeiten-Buttons für Schulen angezeigt werden, die nicht unterhalb der Einrichtung des Verwalters liegen.
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability,manager do
                        ability.can :update, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL],
                        }
                      end
                  },
                  school_leaded_institutions: {
                      name: 'administrierte Schulen',
                      detailed_description: '
                      der Lehrer darf Schulen bearbeiten, in denen er als Schulladmin arbeitet.
                      Es dürfen nirgendwo Bearbeiten-Buttons für Schulen angezeigt werden, in denen der Lehrer nicht als Schuladmin arbeitet.
                      ',
                      user_types: [::Teacher],
                      default_for: [::Teacher],
                      teacher: -> ability, teacher do
                        ability.can :update, ::Institution, {
                            teacher_institution_relations: {
                                teacher_institution_category: { is_school_admin: true },
                                teacher_id: teacher.id
                            }
                        }
                      end
                  },
              }
          },
          destroy: {
              name: 'Löschen',
              scopes: {
                  extern_system_wide: {
                      name: 'Externe Systemweit',
                      detailed_description: '
                       keine Einschränkungen für externe Einrichtungen
                      ',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability do
                        ability.can :destroy, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                      end,
                      teacher: -> ability do
                        ability.can :destroy, ::Institution, {
                            institution_type: ::Institution::TYPE_EXTERN
                        }
                      end
                  },
                  organisational_system_wide: {
                      name: 'Verwaltungseinrichtungen Systemweit',
                      detailed_description: '
                       keine Einschränkungen für Verwaltungseinrichtungen
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :destroy, ::Institution, {
                            institution_type: ::Institution::TYPE_ORGANISATIONAL
                        }
                      end
                  },
                  organisational_own_institutions: {
                      name: 'Verwaltungseinrichtungen im Verwaltungsbereich',
                      detailed_description: '
                      der Verwalter darf Verwaltungseinrichtungen unterhalb seiner eigenen Einrichtung löschen.
                      Es dürfen nirgendwo Löschen-Buttons für eine Einrichtung angezeigt werden, die nicht unterhalb der Einrichtung des Verwalters liegen.
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability,manager do
                        ability.can :destroy, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                      end
                  },
                  organisational_root_institutions: {
                      name: 'Wurzeleinrichtungen',
                      detailed_description: '
                      der Verwalter darf Verwaltungseinrichtungen der obersten Hierarchieebene löschen.
                      Es dürfen nirgendwo Löschen-Buttons für  eine andere Einrichtung als eine solche der obersten Hierarchieebene angezeigt werden.
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :destroy, ::Institution, {
                            parent_id: nil,
                            institution_type: ::Institution::TYPE_ORGANISATIONAL,
                        }
                      end
                  },
                  school_system_wide: {
                      name: 'Schulen Systemweit',
                      detailed_description: '
                      keine Einschränkungen für Schulen
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :destroy, ::Institution, {
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL]
                        }
                      end
                  },
                  school_own_institutions: {
                      name: 'Schulen im Verwaltungsbereich',
                      detailed_description: '
                      der Verwalter darf Schulen unterhalb seiner eigenen Einrichtung löschen.
                      Es dürfen nirgendwo Löschen-Buttons für Schulen angezeigt werden, die nicht unterhalb der Einrichtung des Verwalters liegen.
                      ',
                      user_types: [::Manager],
                      default_for: [::Manager],
                      manager: -> ability,manager do
                        ability.can :destroy, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id},
                            institution_type: [::Institution::TYPE_EDUCATIONAL,::Institution::TYPE_SCHOOL],
                        }
                      end
                  },
              }
          }

      }
      end
  end
end