class CareerItemsLevelController < ApplicationController

  before_action :set_client, only: [:index, :new, :create]

  def index
    add_breadcrumb "SchülerInnen", :clients_path, title: "alle SchülerInnen anzeigen"
    add_breadcrumb "#{view_context.show_person(@client)}", dashboard_client_path(@client), title: "Übersicht anzeigen"
    add_breadcrumb "Laufbahn", client_career_items_path(@client), title: "gesamte Laufbahn anzeigen"
    add_breadcrumb "#{CareerItem::CHANGE_TYPES[1]}"

    @career_items_grid = CareerItemsLevelGrid.new(params[:career_items_level_grid]) do |scope|
      scope.where(client_id: params[:client_id]).page(params[:page]).per(25)
    end
  end

  def new
    authorize!(:update, @client)
    add_breadcrumb "SchülerInnen", :clients_path, title: "alle SchülerInnen anzeigen"
    add_breadcrumb "#{view_context.show_person(@client)}", dashboard_client_path(@client), title: "Übersicht anzeigen"
    add_breadcrumb "#{CareerItem::CHANGE_TYPES[1]}"

    @career_item = @client.career_items.build({change_type: CareerItem::CHANGE_TYPE_LEVEL})
  end

  def create
    @client.assign_attributes(client_params)
    authorize!(:update, @client)
    respond_to do |format|
      if @client.save
          success = "Die neue Förderstufe wurde erfolgreich gespeichert. Die Laufbahn von " + view_context.show_person(@client) + " wurde entsprechend aktualisiert."
          format.html { redirect_to dashboard_client_url(@client), {success: success} }
        format.html { redirect_to dashboard_client_path(@client), success: success }
      else
        format.html { render :new }
      end
    end
  end


  private
    # Use callbacks to share common setup or constraints between actions.

    def client_params
      params.require(:client).permit(:portfolio_level, career_items_attributes: [:change_type, :description])
    end

    def set_client
      @client = Client.find(params[:client_id])
    end
end
