class InstitutionCategoriesController < ApplicationController


  before_action :set_institution_category, only: [:show, :edit, :update, :destroy]

  before_action do
    authorize!(:update, :system_configuration)
  end

  def show
    respond_to {|format|  format.json { } }
  end

  def index
    @grid = InstitutionCategoriesGrid.new(params[:institution_categories_grid]) do |scope|
      scope.page(params[:page]).per(25)
    end
    add_breadcrumb "Einrichtungskategorien", institution_categories_path
  end

  # before show new school form, load instituition categories and then redirect to new school form
  def load
    template = CsbApi::Institution.includes('institution-category').where(school_no: params['school_no']).first
    if template
      model = template.build_model
      unless model.institution_category.present?
        CsbApi::InstitutionCategory.where(region: SystemSetting.get_instance.region).all.map(&:build_model).map(&:save)
      end
    end
    redirect_to new_institution_path(institution_type: Institution::TYPE_SCHOOL, school_no: params['school_no'], parent_id: params['parent_id'])
  end

  def new
    @institution_category = InstitutionCategory.new
    add_breadcrumb "Einrichtungskategorien", institution_categories_path
    add_breadcrumb "Neue Kategorie", new_institution_category_path
  end

  def edit
    add_breadcrumb "Einrichtungskategorien", institution_categories_path
    add_breadcrumb "#{@institution_category.name} bearbeiten", edit_institution_category_path(@institution_category)
  end

  def create
    @institution_category = InstitutionCategory.new(institution_category_params)
    respond_to do |format|
      if @institution_category.save
        format.html { redirect_to institution_categories_path, success: 'Institution category was successfully created.' }
      else
        format.html { render :new }
      end
    end
  end

  def update
    respond_to do |format|
      if @institution_category.update(institution_category_params)
        format.html { redirect_to institution_categories_path, success: 'Institution category was successfully updated.' }
      else
        format.html { render :edit }
      end
    end
  end

  def destroy
    respond_to do |format|
      if @institution_category.is_destructable?
        @institution_category.destroy
        format.html { redirect_to institution_categories_url, success: 'Institution category was successfully destroyed.' }
      else
        format.html { redirect_to institution_categories_url, warning: 'Institution category cannot be destroyed.' }
      end
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_institution_category
      @institution_category = InstitutionCategory.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def institution_category_params
      params.require(:institution_category).permit(:name, :description,
                                                   :normal_education_hours_weekly,
                                                   :special_education_hours_weekly,
                                                   :spare_hours_weekly,
                                                   :allocation_formula_special_ed_level_1,
                                                   :allocation_formula_special_ed_level_2,
                                                   :allocation_formula_special_ed_level_3,
                                                   :institution_type)
    end
end
