class ManagersController < ApplicationController

  before_action :set_manager, only: [:edit, :update,  :edit_roles,:update_roles, :destroy]

  def index
    add_breadcrumb "Verwaltung", :managers_path
    @grid = ManagerGrid.new(params[:manager_grid]) do |scope|
      scope.page(params[:page]).per(25)
    end
  end

  # def show
  #   add_breadcrumb "Verwaltung", :managers_path
  #   add_breadcrumb "#{view_context.show_person(@manager)}", manager_path(@manager)
  # end

  def new
    authorize!(:create,Manager)
    add_breadcrumb "Verwaltung", :managers_path
    add_breadcrumb "neu", :new_manager_path
    @manager = Manager.new((params.fetch(:manager, {}).permit(:institution_id)))
    @manager.identity = User.new
  end

  def edit
    authorize!(:update,@manager)
    add_breadcrumb "Verwaltung", :managers_path
    add_breadcrumb "#{view_context.show_person(@manager)} bearbeiten", edit_manager_path(@manager)
    @manager.build_identity if @manager.identity.nil?
  end

  def edit_roles
    if @manager.identity.nil?
      flash[:danger] = 'Der Verwalter kann sich gar nicht einloggen, daher könne auch keine Rollen vergeben werden'
      redirect_to :back and return
    end
    add_breadcrumb "Verwaltung", :managers_path
    add_breadcrumb "#{view_context.show_person(@manager)} Rollen bearbeiten", edit_manager_path(@manager)
    authorize!(:update_roles,@manager)
  end

  def update_roles
    if @manager.identity.nil?
      flash[:danger] = 'Der Verwalter kann sich gar nicht einloggen, daher könne auch keine Rollen vergeben werden'
      redirect_to :back and return
    end
    authorize!(:update_roles,@manager)
    add_breadcrumb "Verwaltung", :managers_path
    add_breadcrumb "#{view_context.show_person(@manager)} Rollen bearbeiten", edit_manager_path(@manager)
    respond_to do |format|
      if @manager.identity.update(manager_update_roles_params)
        format.html { redirect_to managers_path, success: 'Gespeichert' }
        format.json { render :show, status: :ok, location: @manager }
      else
        flash[:danger] =  'Nicht gespeichert'
        format.html { render :edit_roles }
        format.json { render json: @manager.errors, status: :unprocessable_entity }
      end
    end
  end

  def create
    @manager = Manager.new(manager_params)
    authorize!(:create,@manager)
    respond_to do |format|
      if @manager.save
        format.html { redirect_to institution_path(@manager.institution), success: 'Gespeichert' }
        format.json { render :index, status: :created, location: @manager }
      else
        format.html { render :new }
        format.json { render json: @manager.errors, status: :unprocessable_entity }
      end
    end
  end

  def update
    authorize!(:update,@manager)
    respond_to do |format|
      if @manager.update(manager_params)
        format.html { redirect_to managers_path, success: 'Gespeichert' }
        format.json { render :index, status: :ok, location: @manager }
      else
        format.html { render :edit }
        format.json { render json: @manager.errors, status: :unprocessable_entity }
      end
    end
  end

  def destroy
    authorize!(:destroy,@manager)
    @manager.destroy
    respond_to do |format|
      format.html { redirect_to managers_url, success: 'Gelöscht' }
      format.json { head :no_content }
    end
  end



  private
    # Use callbacks to share common setup or constraints between actions.
    def set_manager
      @manager = Manager.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def manager_params
      params.require(:manager).permit(
        :first_name, :last_name, :gender,:email, :phone, :mobile, :fax, :website, :institution_id,
        :can_log_in, identity_attributes: [:email, :password, :password_confirmation]
        )
    end

  def manager_update_roles_params
    unless current_user.super_admin?
      return params.require(:user).permit(auth_role_ids:[])
    else
      return params.require(:user).permit(:super_admin, auth_role_ids:[])
    end
  end


end
