class NotificationsController < ApplicationController

  before_action :set_notification, only: [ :show, :destroy]


  def index
    authorize!(:read, Notification)
    add_breadcrumb "Benachrichtigungen", :notifications_path, title: "alle Benachrichtigungen anzeigen"    
    @notificationable_type = params[:notificationable]
    @grid = UserMessageGrid.new(params[:notification_grid]) do |scope|
      scope = scope.only_type(@notificationable_type) if @notificationable_type
      scope = scope.accessible_by(current_ability)
      scope.page(params[:page]).per(10)
    end
  end

   def show
     if @notification.is_manual_confirmable?
       redirect_to @notification.confirm_at_path and return
     else
       redirect_to @notification.confirm_at_path and return
     end
   end

  def destroy
    redirect_to :show unless @notification.is_manual_confirmable?
    authorize!(:destroy, @notification)
    if @notification.destroy
      flash[:success] = "Gelöscht: #{@notification.content}"
    else
      flash[:danger] = "Löschen fehlgeschlagen: #{@notification.content}"
    end
    redirect_to @notification.confirm_at_path and return
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_notification
      @notification = Notification.where(id: params[:id]).take
      (redirect_to :back and return) unless @notification.present?
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def notification_params
      params.require(:notification).permit(:content, :start, :type, :notificationable_id, :notificationable_type, :prio)
    end
end
