class TeacherCategoriesController < ApplicationController

  before_action :set_teacher_category, only: [:show, :edit, :update, :destroy]

  before_action do
    authorize!(:update, :system_configuration)
  end

  def index
    @teacher_categories_grid = TeacherCategoriesGrid.new(params[:teacher_categories_grid]) do |scope|
      scope.page(params[:page]).per(5)
    end
    add_breadcrumb "Systemeinstellungen", configurations_path
    add_breadcrumb "Lehrämter", teacher_categories_path
  end


  def new
    @teacher_category = TeacherCategory.new
    add_breadcrumb "Systemeinstellungen", configurations_path
    add_breadcrumb "Lehrämter", teacher_categories_path
    add_breadcrumb "Neu erstellen", new_teacher_category_path
  end

  def edit

    add_breadcrumb "Systemeinstellungen", configurations_path
    add_breadcrumb "Lehrämter", teacher_categories_path
    add_breadcrumb "#{@teacher_category.name} bearbeiten", edit_teacher_category_path(@teacher_category)
  end

  def create
    @teacher_category = TeacherCategory.new(teacher_category_params)
    respond_to do |format|
      if @teacher_category.save
        format.html { redirect_to teacher_categories_path, success: 'Gespeichert' }
      else
        format.html { render :new }
      end
    end
  end

  def update
    respond_to do |format|
      if @teacher_category.update(teacher_category_params)
        format.html { redirect_to teacher_categories_path, success: 'Gespeichert' }
      else
        format.html { render :edit }
      end
    end
  end

  def destroy
    respond_to do |format|
      if @teacher_category.is_destructable?
        @teacher_category.destroy
        format.html { redirect_to teacher_categories_path, success: 'Gelöscht' }
      else
        format.html { redirect_to teacher_categories_path, warning: 'Kann nicht gelöscht werden.' }
      end
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_teacher_category
      @teacher_category = TeacherCategory.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def teacher_category_params
      params.require(:teacher_category).permit(:name, :description, :is_special_ed, :is_support_teacher)
    end
end
