class CareerItemsInstitutionGrid < BaseGrid

  scope do
    CareerItem.order(start_at: :desc,created_at: :desc).where(change_type: CareerItem::CHANGE_TYPE_INSTITUTION)
  end


  filter(:description, :string, header: 'Notizen ') do |value|
    self.where(["career_items.description LIKE ?",  "%#{value}%"])
  end
  
  filter(:institution, :string, header: 'Einrichtung ') do |value|
    self.where(["career_items.institution_name LIKE ?",  "%#{value}%"])
  end


  column(:change_text, header: "Einrichtung", html: true)  do |ci|
    show_career_item_change_text(ci)
  end

  column(:start_at, header: "Beginn")  do |i|
    format(i.start_at) do |date|
      I18n.l(date,format: :short)
    end
  end

  column(:end_at, header: "Ende")  do |i|
    format(i.end_at) do |date|
      date.nil? ? '--' : I18n.l(date,format: :short)
    end
  end
  
  column(:description, header: "Notizen", html: true) do |item|
    
    if description = item.description

      id = "description"+item.id.to_s+"Modal"

      modal = '<div class="modal fade" id="'+id+'" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
          <div class="modal-dialog" role="document">
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Schließen">
                  <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title" id="myModalLabel">Notizen</h4>
              </div>
              <div class="modal-body">
                '+description+'
              </div>
            </div>
          </div>
        </div>'

      button = truncate(description, length: 50) {
        button_tag("(weiterlesen)", {
            class: "btn-link",
            type: "button",
            title: "weitere Informationen anzeigen",
            "data-toggle": "modal",
            "data-target": "##{id}",
          })
        }.html_safe

      button + modal.html_safe
    end
  end

  column(:actions,  header: '', style: 'width:100px', :html => true) do |i|
    "<div class='btn-group btn-group-nowrap btn-group-xs  pull-right' >
      <a href='#{edit_client_career_item_path(i.client, i)}' role='button' class='btn btn-success btn-sm'>
        <i class='glyphicon glyphicon-pencil'></i>
      </a>
    </div>".html_safe
  end

end