class BatchImporterClientGroup < BatchImporter

  def initialize
    super
    @model_collector_class=ClientGroupModelCollector
  end
  private
  class ClientGroupModelCollector < ModelCollector
    def get_model_helper(parent_model)
      case parent_model
        when ::ClientGroup
          return ModelHelperClientGroup.new(parent_model)
        # when ::TeacherInstitutionRelation
        #   return ModelHelperTeacherInstitutionRelation.new(parent_model)
        # when ::TeacherCategory
        #   return ModelHelperBase.new(parent_model) # this helper does not allow any deeper relations
      end
    end

    def self.available_fields
      {
          'client_group.id' => 'Primärschlüssel. Wird nur zur Abfrage der Klasse benutzt',
          'client_group.institution_id' => 'Primärschlüssel der zugehörigen Einrichtung. Wird alternativ nur zur Abfrage der Einrichtung benutzt.',
          'client_group.institution_school_no' => 'Schulnummer der zugehörigen Einrichtung. Wird alternativ nur zur Abfrage der Einrichtung benutzt.',
          'client_group.institution_name' => 'Name der zugehörigen Einrichtung. Wird alternativ zusammen mit semester_name und name zur Abfrage der Klasse benutzt, kann aber auch geschrieben werden.',
          'client_group.semester_id' => 'Primärschlüssel des Schuljahres. Wird zur Abfrage des Schuljahres benutzt, kann aber auch geschrieben werden.',
          'client_group.semester_name' => 'Name des Schuljahres. Wird alternativ zusammen mit institution_name und name zur Abfrage benutzt, kann aber auch geschrieben werden.',
          'client_group.name' => 'Name der Klasse. Wird alternativ zusammen mit semester_name und institution_name zur Abfrage benutzt, kann aber auch geschrieben werden.',
          'client_group.teacher_id' => 'Primärschlüssel des Klassenlehrers. Wird nur zur Abfrage benutzt',
          'client_group.teacher_first_name' => 'Vorname des Klassenlehrers. Wird alternativ zu id zusammen mit teacher_last_name und institution_name zur Abfrage benutzt',
          'client_group.teacher_last_name' => 'Nachname des Klassenlehrers. Wird alternativ zu id  teacher_first_name und institution_name zur Abfrage benutzt',
          'client_group.normal_education_hours' => 'Wöchentlicher Stundesatz für die Klasse.',
          'client_group.description' => 'Beschreibung der Klasse',
          'client_group.clients_total' => 'Gesamtzahl an Schülern',
          'client_group.special_education_hours' => 'Wöchentlicher Stundensatz sonderpädagogik',
          'client_group.teacher_email' => 'Email des Klassenlehrers. Wird alternativ zu id zur Abfrage benutzt',
      }
    end
  end

    class ModelHelperClientGroup < ModelHelperBase
      private
      def execute_query(token,attributes)
        case token
          when 'client_group' # query an existing client_group instance
            return ::ClientGroup.where(id: attributes['id']).take if attributes['id']
            if attributes['institution_id']
              return ::ClientGroup.joins('institutions')
                         .where('institutions.id=?',attributes['institution_id']).take
            end
            if attributes['institution_name'] && attributes['semester_name'] && attributes['name']
              return ::ClientGroup.joins('institutions').joins('semesters')
                         .where('institutions.name=?',attributes['institution_name'])
                         .where('semester.name=?',attributes['semester_name'])
                         .where(name: attributes['name']).take
            end
          when 'teacher'
            # we query for global teacher and set it on client_group
            return @model.teacher = ::Teacher .where(id: attributes['teacher_id']).take if attributes['teacher_id']
            if attributes['teacher_first_name'] &&  attributes['teacher_last_name'] && attributes['institution_name']
              return @model.teacher = ::Teacher.joins('institutions')
                                          .where('institutions.name=?',attributes['institution_name'])
                                          .where(last_name: attributes['teacher_last_name'])
                                          .where(first_name: attributes['teacher_first_name'])
                                          .take
            end
            if attributes['teacher_first_name'] &&  attributes['teacher_last_name'] && attributes['institution_name']
              return @model.teacher = ::Teacher.where(email: attributes['teacher_email']).take
            end
          when 'institution'
            return @model.institution = ::Institution.where(id: attributes['institution_id']).take if attributes['institution_id']
            if attributes['institution_school_no']
              return @model.institution = ::Institution.where(school_no: attributes['institution_school_no']).take if attributes['institution_school_no']
            end
            if attributes['institution_name']
              return @model.institution = ::Institution.where(name: attributes['institution_name']).take if attributes['institution_name']
            end
          when 'semester'
            return @model.semester = ::Semester.where(id: attributes['semester_id']).take if attributes['semester_id']
            if attributes['semester_name']
              return @model.semester = ::Semester.where(name: attributes['semester_name']).take if attributes['semester_name']
            end
        end
      end
      def execute_create(token, attributes)
        case token
          when 'client_group' # create a new teacher instance
            return ::ClientGroup.new(attributes)
          when 'teacher'
            return nil #it is not allowed to create a new teacher by this importer
          when 'institution'
            return nil #it is not allowed to create a new institution by this importer
          when 'semester'
            return nil #it is not allowed to create a new semester by this importer
        end
      end
      def allow_attribute(token,name,value)
        case token
          when 'client_group' # create a new teacher instance
            r=  %w(normal_education_hours name description clients_total special_education_hours).include? name
          when 'teacher'
            r= false # it is not allowed to change a teacher category by this importer
          when 'institution'
            r= false # it is not allowed to change an institution category by this importer
          when 'semester'
            r= false # it is not allowed to change a semester category by this importer
        end
        r
      end
    end

    class ModelHelperTeacherInstitutionRelation <  ModelHelperBase
      private
      def execute_query(token,attributes)
        case token
          when 'institution'
            #as the relations are always new, we query globally and set it
            return @model.institution = ::Institution.where(id: attributes['id']).take if attributes['id']
            return @model.institution = ::Institution.where(school_no: attributes['school_no']).take if attributes['school_no']
            return @model.institution = ::Institution.where(name: attributes['name']).take if attributes['name']
          when 'portfolio_specialization'
            return @model.portfolio_specialization = ::PortfolioSpecialization.where(name: attributes['name']).take if attributes['name']
          when 'teacher_institution_category'
            return @model.teacher_institution_category = ::TeacherInstitutionCategory.where(name: attributes['name']).take if attributes['name']
        end
      end
      def execute_create(token, attributes)
        case token
          when 'institution'
            return nil #this importer does not allow to create new institutions
          when 'portfolio_specialization'
            return nil #this importer does not allow to create new portfolio_specialization
          when 'teacher_institution_category'
            return nil #this importer does not allow to create new teacher_institution_category
        end
      end
      def allow_attribute(name,value,token)
        case token
          when 'institution' # create a new teacher instance
            return false # this importer does not allow update of institution
          when 'portfolio_specialization'
            return false # this importer does not allow update of portfolio_specialization
          when 'teacher_institution_category'
            return false # this importer does not allow update of portfolio_specialization
        end
      end

    end
end
