class BatchImporterTeacher < BatchImporter

  def initialize
    super
    @model_collector_class=TeacherModelCollector
  end
  private
  class TeacherModelCollector < ModelCollector
    def get_model_helper(parent_model)
      case parent_model
        when ::Teacher
          return ModelHelperTeacher.new(parent_model)
        when ::TeacherInstitutionRelation
          return ModelHelperTeacherInstitutionRelation.new(parent_model)
      end
    end

    def self.available_fields
      {
          'teacher.id' => 'Primärschlüssel. Wird nur zur Abfrage benutzt',
          'teacher.first_name' => 'Vorname. Wird zusammen mit teacher.last_name zur Abfrage benutzt, kann aber auch geschrieben werden, wenn teacher.id gesetzt ist',
          'teacher.last_name' => 'Nachname. Wird zusammen mit teacher.first_name zur Abfrage benutzt, kann aber auch geschrieben werden, wenn teacher.id gesetzt ist',
          'teacher.gender' => 'Geschlecht. Wird geschrieben  wenn gesetzt [männlich|weiblich]',
          'teacher.email' =>  'Email. Wird geschrieben wenn gesetzt',
          'teacher.phone' =>  'Telefon. Wird geschrieben wenn gesetzt',
          'teacher.mobile' =>  'Mobilnummer. Wird geschrieben wenn gesetzt',
          'teacher.fax' =>  'Faxnummer. Wird geschrieben wenn gesetzt',
          'teacher.website' =>  'Webseite. Wird geschrieben wenn gesetzt',
          'teacher.teacher_category.name' => 'Lehramt. Wird nur zur Abfrage benutzt',
          'teacher.identity.email'=> 'Email für den Login. Wird geschrieben wenn gesetzt',
          'teacher.identity.password' =>  'Passwort für den Login. Wird geschrieben wenn gesetzt',
          'teacher.identity.password_confirmation' =>  'Passwort wiederholung für den Login. Wird geschrieben wenn gesetzt',
          'teacher.teacher_institution_relations.institution.id' => 'Primärschlüssel einer Schule. Wird nur zur Abfrage benutzt',
          'teacher.teacher_institution_relations.institution.school_no' => 'Schulnummer. Wird nur zur Abfrage benutzt, alternative zu id',
          'teacher.teacher_institution_relations.institution.name' => 'Name einer Schule. Wird nur zur Abfrage benutzt, alternative zu id und school_no',
          'teacher.teacher_institution_relations.normal_education_part_time' =>  'Wochenstunden Unterricht an der Schule. Wird geschrieben wenn gesetzt',
          'teacher.teacher_institution_relations.special_education_part_time' =>  'Wochenstunden sonderpädagogisch  an der Schule. Wird geschrieben wenn gesetzt',
          'teacher.teacher_institution_relations.spare_time'=>  'Sonstige Zeiten in Std  an der Schule. Wird geschrieben wenn gesetzt',
          'teacher.teacher_institution_relations.portfolio_specialization.name' => 'Förderschwerpunkt an der Schule. Wird nur zur Abfrage benutzt',
          'teacher.teacher_institution_relations.teacher_institution_category.name' => 'Einsatzart an der Schule. Wird nur zur Abfrage benutzt',
      }
    end
  end

    class ModelHelperTeacher < ModelHelperBase
      private
      def execute_query(token,attributes)
        case token
          when 'teacher' # query an existing teacher instance
            return ::Teacher.where(id: attributes['id']).take if attributes['id']
            return ::Teacher.where(email: attributes['email']).take if attributes['email']
            return ::Teacher.where(first_name: attributes['first_name'], last_name: attributes['last_name']).take if attributes['first_name'] && attributes['last_name']
          when 'teacher_category'
            # we query for global teacher category and set it on teacher
            return @model.teacher_category = ::TeacherCategory.where(name: attributes['name']).take if attributes['name']
          when 'identity'
            # here, we always return the existing identity
            return @model.identity
          when 'teacher_institution_relations'
            # these are always created new. There is validation to ensure unique institution
            return @model.teacher_institution_relations.none
        end
      end
      def execute_create(token, attributes)
        case token
          when 'teacher' # create a new teacher instance
            return ::Teacher.new(attributes)
          when 'teacher_category'
            return nil #it is not allowed to create a new category by this importer
          when 'identity'
            # it is possible to set a new identity on teacher if it does not have one
            return @model.identity = ::User.new(attributes)
          when 'teacher_institution_relations'
            return @model.teacher_institution_relations.build(attributes)
        end
      end
      def allow_attribute(token,name,value)
        case token
          when 'teacher' # create a new teacher instance
            r=  %w(first_name last_name gender email phone mobile fax website ).include? name
          when 'teacher_category'
            r= false # it is not allowed to change a teacher category by this importer
          when 'identity'
            r= %w(email password password_confirmation).include? name
          when 'teacher_institution_relations'
            r= %w(normal_education_part_time special_education_part_time spare_time).include? name
        end
        r
      end
    end

    class ModelHelperTeacherInstitutionRelation <  ModelHelperBase
      private


      def execute_query(token,attributes)
        case token
          when 'institution'
            #as the relations are always new, we query globally and set it
            return @model.institution = ::Institution.education_facilities.where(id: attributes['id']).take if attributes['id']
            return @model.institution = ::Institution.education_facilities.where(school_no: attributes['school_no']).take if attributes['school_no']
            return @model.institution = ::Institution.education_facilities.where(name: attributes['name']).take if attributes['name']
          when 'portfolio_specialization'
            return @model.portfolio_specialization = ::PortfolioSpecialization.where(name: attributes['name']).take if attributes['name']
          when 'teacher_institution_category'
            return @model.teacher_institution_category = ::TeacherInstitutionCategory.where(name: attributes['name']).take if attributes['name']
        end
      end
      def execute_create(token, attributes)
        case token
          when 'institution'
            return nil #this importer does not allow to create new institutions
          when 'portfolio_specialization'
            return nil #this importer does not allow to create new portfolio_specialization
          when 'teacher_institution_category'
            return nil #this importer does not allow to create new teacher_institution_category
        end
      end
      def allow_attribute(name,value,token)
        case token
          when 'institution' # create a new teacher instance
            return false # this importer does not allow update of institution
          when 'portfolio_specialization'
            return false # this importer does not allow update of portfolio_specialization
          when 'teacher_institution_category'
            return false # this importer does not allow update of portfolio_specialization
        end
      end

    end
end
