class AnnounceDuplicateTotalJob < ActiveJob::Base
  queue_as :default

  rescue_from ActiveJob::DeserializationError do |e|
    message = "\e[31m\e[1m#{e.message}\e[22m\e[0m" # make read and bold
    Rails.logger.error(message)
  end

  def perform(*client_duplicate_detection_requests)
    client_duplicate_detection_requests.each do |client_duplicate_detection_request|
      # set the total at csb
      begin
        query = CsbApi::ClientDuplicateDetectionQuery.where(id: client_duplicate_detection_request.client_duplicate_detection_query_id).first
        if query.update_attributes({
           'announced-client-duplicate-detection-results-count' => client_duplicate_detection_request.announced_duplicate_count
        })
          set_success(client_duplicate_detection_request)
        else
          set_fatal_error(client_duplicate_detection_request,query.errors.full_messages.join(', '))
        end
      rescue JsonApiClient::Errors::ConnectionError, JsonApiClient::Errors::ServerError => e
        set_recoverable_error(client_duplicate_detection_request,e.message)
      rescue StandardError, JsonApiClient::Errors::ValidationError => e
        set_fatal_error(client_duplicate_detection_request,e.message)
      end
    end
  end

  private
  def set_success(client_duplicate_detection_request)
    client_duplicate_detection_request.announcement_performed!
    Rails.logger.debug("Successfully announced total for duplicate detection query: #{client_duplicate_detection_request.client_duplicate_detection_query_id}")
  end
  def set_recoverable_error(client_duplicate_detection_request,message)
    if client_duplicate_detection_request.retry_count <= 2
      client_duplicate_detection_request.increment! :retry_count
      retry_job wait: (client_duplicate_detection_request.retry_count * client_duplicate_detection_request.retry_count).seconds
      client_duplicate_detection_request.announcement_retry!
      Rails.logger.info(message)
    else
      client_duplicate_detection_request.announcement_failed!
      message = "\e[31m\e[1m#{message}\e[22m\e[0m" # make read and bold
      Rails.logger.error(message)
    end
  end
  def set_fatal_error(client_duplicate_detection_request,message)
    client_duplicate_detection_request.announcement_failed!
    message = "\e[31m\e[1m#{message}\e[22m\e[0m" # make read and bold
    Rails.logger.error(message)
  end
end
