class Address < ActiveRecord::Base


  has_one  :institution, inverse_of: :address

  validates :street, :number, :city, :region, :zip, :country, presence: true

  alias_attribute :lat, :latitude
  alias_attribute :lng, :longitude
  alias_attribute :state, :region


  def self.create_from_geocoder_result(address_geocoder_search_result)
    new.tap do |instance|
      %w(street number city region zip country latitude longitude).each do |part|
        instance.send("#{part}=",address_geocoder_search_result.send(part).to_s.strip) if  address_geocoder_search_result.send(part).to_s.strip.present?
      end
    end
  end

  def country_name
    map = {'DE' => 'Deutschland'}
    map[self.country]
  end

  def to_s
    parts = []
    unless self.street.nil? && self.number.nil?
      parts << "#{self.street.to_s.strip} #{self.number.to_s.strip}"
    end
    unless self.zip.nil? && self.city.nil?
      parts << "#{self.zip.to_s.strip} #{self.city.to_s.strip}"
    end
    if parts.any? && ! (self.region.nil? && self.country.nil?)
      parts << "#{self.region.to_s.strip} #{self.country_name.to_s.strip}"
    end
    parts.join(',') if parts.any?
  end


  def clear
    %w(street number city region zip country latitude longitude).each do |part|
      self.send("#{part}=",nil)
    end
  end

end
