class ClientDuplicateDetectionRequest < ActiveRecord::Base
  has_many :client_duplicate_detections, dependent: :destroy
  enum result_code: [ :request_initial,:request_performed, :request_failed ]
  enum announcement_result_code: [ :announcement_initial,:announcement_performed, :announcement_failed, :announcement_retry ]


  validates :client_duplicate_request_id, presence: true # this is the original request id on the vsb that created the duplicate request
  validates :vsb_id, presence: true # this is the id of the vsb that created the duplicate request
  validates :client_duplicate_detection_query_id, presence: true # this is the query id at csb for this request
  validates :bday, presence: true # bday that must be checked on this system
  validates :first_name, presence: true # first_name that must be checked on this system
  validates :last_name, presence: true # last_name that must be checked on this system
  validates :gender, presence: true # gender that must be checked on this system

  after_create do
    PerformClientDuplicateDetectionRequestJob.perform_later(self)
    # After 10 seconds, the job is cancelled, regardless of the return status.
    FinishClientDuplicateDetectionRequestJob.set(wait: 10.seconds).perform_later(self)
    true
  end

end
