module Institutions
  class AllocationStats

    # normal education, hours always weekly
    attr_reader :ne_hours_available # alle freien stunden ( pro woche ) für Normale Lehre an der Schule # OK
    attr_reader :ne_teachers_count # alle Lehrer in der Regellehre, also alle Lehrer der Schule die zumindest einen Anteil Regellehre haben
    attr_reader :ne_clients_count # alle Schüler in der Regellehre, also alle Schüler der Schule
    attr_reader :ne_hours_required # wöchentlicher stundenbedarf in der Regellehre an der Schule
    attr_reader :ne_hours_available_carry # zwischenergebnis noch frei stunden in der regellehre an der Schule

    # special education, hours always weekly
    attr_reader :client_groups_count
    attr_reader :se_hours_available # alle freien stunden ( pro woche ) für sonder Lehre an der Schule
    attr_reader :se_teachers_count # alle Lehrer in der sonder, also alle Lehrer der Schule die zumindest einen Anteil sonder haben
    attr_reader :se_clients_count # alle Schüler in Förderstufe 0, also alle explizit für Level 0 eingetragenen Schüler
    attr_reader :se_hours_required # wöchentlicher stundenbedarf in der Sonderlehre an der Schule
    attr_reader :se_clients_count_l_1 # alle Schüler in Förderstufe 1, also alle explizit für Level 1 eingetragenen Schüler
    attr_reader :se_hours_required_l_1 # wöchentlicher stundenbedarf in der Sonderlehre FS1 an der Schule
    attr_reader :se_clients_count_l_2 # alle Schüler in Förderstufe 2, also alle explizit für Level 2 eingetragenen Schüler
    attr_reader :se_hours_required_l_2 # wöchentlicher stundenbedarf in der Sonderlehre FS2 an der Schule
    attr_reader :se_clients_count_l_3 # alle Schüler in Förderstufe 3, also alle explizit für Level 3 eingetragenen Schüler
    attr_reader :se_hours_required_l_3 # wöchentlicher stundenbedarf in der Sonderlehre FS3 an der Schule (durch alle level 3 schüler)
    attr_reader :se_hours_required_also_ne # zwischenergebnis sonderbedarf ohne level 3, kann auch durch regellehrerstellen gedeckt sein
    attr_reader :se_hours_required_carry_l_3 # zwischenergebnis sonderbedarf level 3, nach deckung durch regellehrer
    attr_reader :se_hours_required_only_se # bedarf fs 3 und noch offener bedarf, nur deckung durch sonderpäds
    attr_reader :se_hours_required_total # letztlich noch offener Bedarf ( oder, wenn negativ, offene stunden)

   

    def initialize(institution)
        @institution                  = institution
        @ne_teachers_count            = (@institution.teacher_institution_relations.length) || 0
        @se_teachers_count            = (@institution.teacher_institution_relations.length) || 0
        @ne_hours_available           = (@institution.teacher_institution_relations.inject(0) { |s, t| s + ( t.normal_education_part_time || 0 ) }) || 0 # OK
        @ne_clients_count             = (@institution.current_client_groups.map(&:clients_total).inject(&:+)) || 0
        @client_groups_count          = (@institution.current_client_groups.length) || 0
        @ne_hours_required            = (@institution.client_groups.inject(0){|s,cg| s + (cg.normal_education_hours || 0 )  }) || 0
        @ne_hours_available_carry     = (@ne_hours_available - @ne_hours_required) || 0
        @se_clients_count             = (@institution.clients.where(portfolio_level: 0).length) || 0
        @se_hours_required            = (@institution.client_groups.inject(0){|s,cg| s + (cg.special_education_hours || 0 ) }) || 0
        @se_clients_count_l_1         = (@institution.clients.where(portfolio_level: 1).length) || 0
        @se_hours_required_l_1        = (@se_clients_count_l_1 * ( @institution.allocation_formula_special_ed_level_1 || 0 ) ) || 0
        @se_clients_count_l_2         = (@institution.clients.where(portfolio_level: 2).length) || 0
        @se_hours_required_l_2        = (@se_clients_count_l_2 * ( @institution.allocation_formula_special_ed_level_2 || 0 )) || 0
        @se_hours_required_also_ne    = (@se_hours_required + @se_hours_required_l_1 + @se_hours_required_l_2) || 0
        @se_hours_required_carry_l_3  = (@se_hours_required_also_ne - ( @ne_hours_available_carry > 0 ? @ne_hours_available_carry : 0 )) || 0
        @se_hours_required_carry_l_3  = 0 if @se_hours_required_carry_l_3 < 0
        @se_clients_count_l_3         = (@institution.clients.where(portfolio_level: 3).length) || 0
        @se_hours_required_l_3        = (@se_clients_count_l_3 * ( @institution.allocation_formula_special_ed_level_3 || 0 ) ) || 0
        @se_hours_required_only_se    = (@se_hours_required_carry_l_3 + @se_hours_required_l_3) || 0
        @se_hours_available           = (@institution.teacher_institution_relations.inject(0) { |s, t| s + ( t.special_education_part_time || 0)   }) || 0
        @se_hours_required_total      = (@se_hours_required_only_se - @se_hours_available) || 0
    end

  end
end