module SystemTasks
  class EducationalCourseViolations < Base

    def _escalations
      [
          {
              Escalator::SendUserMessage => [target.teacher,target.client_group.teacher]
          },
          {
              Escalator::SendUserMessage => target.institution.teacher_institution_relations.joins(:teacher_institution_category).where(teacher_institution_categories:{is_school_admin:true}).all.to_a
          },
          {
              Escalator::SendUserMessage => Manager.where(institution_id: InstitutionHierarchy.where(child_id: target.institution_id).select(:parent_id)).all.to_a
          }
      ]
    end

    def is_manual_confirmable?
      false
    end

    class << self
      def subscribe_to
        [
            {
                klass: 'client',
                callback: 'after_save',
                handler: 'client_after_save'
            }
        ]
      end


      def client_after_save(client)
        if client.changes.has_key? 'client_group_id'
          where(target: client).destroy_all
          if  client.violated_course_rules.any?
            create({
               target: client,
               client: client,
               institution: nil,
               label: client.full_name,
               title:  "Die Regeln für die Bildungsgänge sind verletzt durch #{client.first_name}  #{client.last_name}",
               message:  client.violated_course_rules.map(&:violation_message).join(', '),
               start_at: DateTime.now,
               due_at:  DateTime.now,
               next_escalation:  DateTime.now,
               escalation_delay: 86400 * 7,
               resolve_location: Rails.application.routes.url_helpers.dashboard_client_path(client)
           })
          end
        end
      end
    end


  end
end