module SystemTasks
  class ManagementConference < Base
    def _escalations
      if target.subject.is_a? Client
        return  [
            {
                Escalator::SendUserMessage => [target.subject.teacher,target.subject.client_group.teacher]
            },
            {
                Escalator::SendUserMessage => target.subject.institution.teacher_institution_relations.joins(:teacher_institution_category).where(teacher_institution_categories:{is_school_admin:true}).all.to_a
            }
        ]
      end
      if target.subject.is_a? ClientGroup
        return  [
            {
                Escalator::SendUserMessage => [target.subject.teacher]
            },
            {
                Escalator::SendUserMessage => target.subject.institution.teacher_institution_relations.joins(:teacher_institution_category).where(teacher_institution_categories:{is_school_admin:true}).all.to_a
            }
        ]
      end
    end

    def is_manual_confirmable?
      false
    end



    class << self
      def subscribe_to
        [
            {
                klass: 'portfolio/item',
                callback: 'before_save',
                handler: 'portfolio_item_change'
            },
            {
                klass: 'portfolio/item',
                callback: 'after_destroy',
                handler: 'portfolio_item_change'
            }
        ]
      end


      def portfolio_item_change(portfolio_item)
        if (portfolio_item.portfolio_step.allowed?(:management_conference) && (portfolio_item.management_conference_changed? || portfolio_item.destroyed)) || portfolio_item.portfolio_step.type == 'management_conference'
          conference_required = false
          last_requiring_item = nil
          last_fulfilling_item = nil
          enumerator = ::Portfolio::Enumerator.new( portfolio_item.portfolio.portfolio_items)
          enumerator.each do |item|
            if portfolio_item.portfolio_step.type == 'management_conference'
              conference_required = false
              last_fulfilling_item = item
            end
            if item.management_conference?
              conference_required = true
              last_requiring_item = item
            end
          end
          if conference_required && last_requiring_item
            unless where(target: last_requiring_item.portfolio).exists?
              create({
                   target: last_requiring_item.portfolio,
                   client: (last_requiring_item.portfolio.subject.is_a? Client) ? last_requiring_item.portfolio.subject : nil,
                   institution: (last_requiring_item.portfolio.subject.is_a? ClientGroup) ? last_requiring_item.portfolio.subject_proxy.institution : nil,
                   label: last_requiring_item.portfolio.subject_proxy.name,
                   title:   "Ein Schulleitungsgespräch für #{last_requiring_item.portfolio.subject_proxy.name} ist angesetzt.",
                   message:   ::I18n.translate('system_notifications.management_conference.content',
                                               step: last_requiring_item.portfolio.subject_proxy.name,
                                               step_date: ::I18n.localize(last_requiring_item.start,format: :short),
                                               management_conference_date: ::I18n.localize(last_requiring_item.management_conference_date,format: :short),
                   ),
                   start_at: last_requiring_item.start,
                   due_at:  last_requiring_item.management_conference_date,
                   next_escalation:  last_requiring_item.start,
                   escalation_delay: 86400 * 7,
                   resolve_location: last_requiring_item.portfolio.subject_proxy.resolve_notifications_path
               })
            end
          else
            if last_fulfilling_item
              where(target: last_fulfilling_item.portfolio).delete_all
            end
          end
        end
      end


    end
    end
end