class SetUpSchema < ActiveRecord::Migration
  def change
    create_table "addresses", force: :cascade do |t|
      t.string   "street"
      t.string   "city"
      t.string   "region"
      t.string   "zip"
      t.string   "country"
      t.datetime "created_at", null: false
      t.datetime "updated_at", null: false
      t.string   "number"
      t.float    "latitude"
      t.float    "longitude"
    end

    add_index "addresses", ["latitude", "longitude"], name: "index_addresses_on_latitude_and_longitude", unique: true, using: :btree

    create_table "career_items", force: :cascade do |t|
      t.string   "name"
      t.text     "description"
      t.datetime "start"
      t.datetime "end"
      t.boolean  "active"
      t.datetime "created_at",  null: false
      t.datetime "updated_at",  null: false
      t.integer  "client_id"
      t.integer  "institution_id"
    end

    add_index "career_items", ["client_id"], name: "index_career_item_on_client_id", using: :btree
    add_index "career_items", ["institution_id"], name: "index_career_item_on_institution_id", using: :btree

    create_table "career_item_teacher_relations", force: :cascade do |t|
      t.datetime "created_at",  null: false
      t.datetime "updated_at",  null: false
      t.integer  "career_item_id"
      t.integer  "teacher_id"
      t.boolean  "is_primary"
    end

    add_index "career_item_teacher_relations", ["career_item_id"], name: "index_career_item_teacher_relation_on_career_item_id", using: :btree
    add_index "career_item_teacher_relations", ["teacher_id"], name: "index_career_item_teacher_relation_on_teacher_id", using: :btree

    create_table "institution_categories", force: :cascade do |t|
      t.string   "name"
      t.text     "description"
      t.datetime "created_at",                     null: false
      t.datetime "updated_at",                     null: false
      t.boolean  "is_school",      default: false
      t.boolean  "is_educational"
    end

    create_table "institutions", force: :cascade do |t|
      t.string   "name"
      t.string   "school_no"
      t.integer  "allocation_formula"
      t.string   "email"
      t.string   "fax"
      t.string   "website"
      t.text     "comment"
      t.text     "description"
      t.integer  "institution_category_id"
      t.datetime "created_at",              null: false
      t.datetime "updated_at",              null: false
      t.datetime "updated_at",              null: false
      t.integer  "parent_id"
    end

    add_index "institutions", ["institution_category_id"], name: "index_institutions_on_institution_category_id", using: :btree

    create_table "clients", force: :cascade do |t|
      t.string   "first_name"
      t.string   "last_name"
      t.integer  "gender"
      t.text     "description"
      t.date     "bday"
      t.datetime "created_at",                     null: false
      t.datetime "updated_at",                     null: false
      t.datetime "deleted_at"
      t.integer  "portfolio_level",    default: 0, null: false
    end
    add_index "clients", ["deleted_at"], name: "index_people_on_deleted_at", using: :btree


    create_table "teachers", force: :cascade do |t|
      t.string   "first_name"
      t.string   "last_name"
      t.integer  "gender"
      t.string   "email"
      t.string   "phone"
      t.string   "mobile"
      t.string   "fax"
      t.string   "website"
      t.date     "bday"
      t.datetime "created_at",                     null: false
      t.datetime "updated_at",                     null: false
      t.integer  "teacher_category_id"
    end
    add_index "teachers", ["teacher_category_id"], name: "index_teachers_on_teacher_category_id", using: :btree

    create_table "guardians", force: :cascade do |t|
      t.string   "first_name"
      t.string   "last_name"
      t.integer  "gender"
      t.string   "email"
      t.string   "phone"
      t.string   "mobile"
      t.datetime "created_at",                     null: false
      t.datetime "updated_at",                     null: false
      t.integer  "guardian_category_id"
    end
    add_index "guardians", ["guardian_category_id"], name: "index_guardians_on_guardian_category_id", using: :btree
    # add_index "people", ["deleted_at"], name: "index_people_on_deleted_at", using: :btree
    # add_index "people", ["person_category_id"], name: "index_people_on_person_category_id", using: :btree

    create_table "teacher_categories", force: :cascade do |t|
      t.string   "name"
      t.text     "description"
      t.datetime "created_at",  null: false
      t.datetime "updated_at",  null: false
    end

    create_table "guardian_categories", force: :cascade do |t|
      t.string   "name"
      t.text     "description"
      t.datetime "created_at",  null: false
      t.datetime "updated_at",  null: false
    end

    create_table "teacher_institution_relations", force: :cascade do |t|
      t.integer  "teacher_id"
      t.integer  "institution_id"
      t.datetime "created_at",     null: false
      t.datetime "updated_at",     null: false
    end

    add_index "teacher_institution_relations", ["institution_id"], name: "index_teacher_institution_relations_on_institution_id", using: :btree
    add_index "teacher_institution_relations", ["teacher_id"], name: "index_teacher_institution_relations_on_teacher_id", using: :btree

    create_table "portfolio_item_evaluations", force: :cascade do |t|
      t.text     "result"
      t.boolean  "is_positive"
      t.integer  "portfolio_item_id"
      t.datetime "created_at",        null: false
      t.datetime "updated_at",        null: false
    end

    add_index "portfolio_item_evaluations", ["portfolio_item_id"], name: "index_portfolio_item_evaluations_on_portfolio_item_id", using: :btree

    create_table "portfolio_item_involved_teachers", force: :cascade do |t|
      t.integer  "teacher_id",         null: false
      t.integer  "portfolio_item_id", null: false
      t.datetime "created_at",        null: false
      t.datetime "updated_at",        null: false
    end

    add_index "portfolio_item_involved_teachers", ["teacher_id"], name: "index_portfolio_item_involved_teachers_on_teacher_id", using: :btree
    add_index "portfolio_item_involved_teachers", ["portfolio_item_id"], name: "index_portfolio_item_involved_teachers_on_portfolio_item_id", using: :btree

    create_table "portfolio_item_involved_guardians", force: :cascade do |t|
      t.integer  "guardian_id",         null: false
      t.integer  "portfolio_item_id", null: false
      t.datetime "created_at",        null: false
      t.datetime "updated_at",        null: false
    end

    add_index "portfolio_item_involved_guardians", ["guardian_id"], name: "index_portfolio_item_involved_guardians_on_guardian_id", using: :btree
    add_index "portfolio_item_involved_guardians", ["portfolio_item_id"], name: "index_portfolio_item_involved_guardians_on_portfolio_item_id", using: :btree

    create_table "portfolio_items", force: :cascade do |t|
      t.integer  "portfolio_step_id",                           null: false
      t.integer  "level",                       default: 0,     null: false
      t.integer  "portfolio_specialization_id"
      t.date     "start",                                       null: false
      t.text     "content",                                     null: false
      t.text     "target_agreement",                            null: false
      t.boolean  "parent_teacher_conference",   default: false, null: false
      t.boolean  "management_conference",       default: false, null: false
      t.integer  "portfolio_step_result_id"
      t.integer  "client_id"
      t.datetime "created_at",                                  null: false
      t.datetime "updated_at",                                  null: false
    end

    add_index "portfolio_items", ["client_id"], name: "index_portfolio_items_on_client_id", using: :btree
    add_index "portfolio_items", ["portfolio_specialization_id"], name: "index_portfolio_items_on_portfolio_specialization_id", using: :btree
    add_index "portfolio_items", ["portfolio_step_id"], name: "index_portfolio_items_on_portfolio_step_id", using: :btree
    add_index "portfolio_items", ["portfolio_step_result_id"], name: "index_portfolio_items_on_portfolio_step_result_id", using: :btree

    create_table "portfolio_specializations", force: :cascade do |t|
      t.string   "name"
      t.string   "abbreviation"
      t.datetime "created_at",   null: false
      t.datetime "updated_at",   null: false
    end


    create_table "users", force: :cascade do |t|
      t.string   "email",                  default: "",    null: false
      t.string   "encrypted_password",     default: "",    null: false
      t.string   "reset_password_token"
      t.datetime "reset_password_sent_at"
      t.datetime "remember_created_at"
      t.integer  "sign_in_count",          default: 0,     null: false
      t.datetime "current_sign_in_at"
      t.datetime "last_sign_in_at"
      t.inet     "current_sign_in_ip"
      t.inet     "last_sign_in_ip"
      t.datetime "created_at",                             null: false
      t.datetime "updated_at",                             null: false
      t.boolean  "super_admin",            default: false
      t.boolean  "dev",                    default: false
    end

    add_index "users", ["email"], name: "index_users_on_email", unique: true, using: :btree
    add_index "users", ["reset_password_token"], name: "index_users_on_reset_password_token", unique: true, using: :btree

    add_foreign_key "career_items", "clients"
    add_foreign_key "career_items", "institutions"
    add_foreign_key "career_item_teacher_relations", "teachers"
    add_foreign_key "career_item_teacher_relations", "career_items"
    add_foreign_key "institutions", "institution_categories"
    add_foreign_key "institutions", "institutions", column: "parent_id"
    add_foreign_key "teachers", "teacher_categories"
    add_foreign_key "guardians", "guardian_categories"
    add_foreign_key "teacher_institution_relations", "institutions"
    add_foreign_key "teacher_institution_relations", "teachers"
    add_foreign_key "portfolio_item_evaluations", "portfolio_items"
    add_foreign_key "portfolio_item_involved_teachers", "teachers"
    add_foreign_key "portfolio_item_involved_teachers", "portfolio_items"
    add_foreign_key "portfolio_item_involved_guardians", "guardians"
    add_foreign_key "portfolio_item_involved_guardians", "portfolio_items"
    add_foreign_key "portfolio_items", "clients", column: "client_id"
    add_foreign_key "portfolio_items", "portfolio_specializations"
    # add_foreign_key "portfolio_items", "portfolio_step_results"
    # add_foreign_key "portfolio_items", "portfolio_steps"
    # add_foreign_key "portfolio_step_results", "portfolio_steps"
  end
end
