class CreatePortfolioRules < ActiveRecord::Migration
  def change

    create_table :portfolio_steps do |t|
      t.string   :name
      t.string   :optionals # each of this may be appended
      t.string   :requirements  # parent_teacher_conference | management_conference | advancement_plan & evaluation | diagnostic
      t.integer  :evaluation_time_span_min # "verbindlicher Evaluationszeitraum", should be at minimumn
      t.integer  :evaluation_time_span_max # "verbindlicher Evaluationszeitraum", should be at maximum
      t.text     :description
      t.datetime :created_at,                null: false
    end

    create_table :portfolio_step_results do |t|
      t.string   :name
      t.belongs_to  :step
      t.datetime :created_at,        null: false
    end

    add_column(:portfolio_item_evaluations,:time_span,:integer)

    add_foreign_key "portfolio_items", "portfolio_step_results"
    add_foreign_key "portfolio_items", "portfolio_steps"
    add_foreign_key "portfolio_step_results", "portfolio_steps", column: "step_id"

    # each rule represent an item from the portfolio chain syntax
    create_table :portfolio_rules do |t|
      t.integer :position
      t.integer :time_span
      t.integer :level
      t.text :description # Description, like "1. Portfolio: Elterngespräch incl. Einwilligungserklärung (Beratungsantrag)."
      t.datetime :created_at, null: false
    end

    # contain the necessary an allowed steps for rules
    create_table :portfolio_rule_steps do |t|
      t.belongs_to :rule
      t.belongs_to :step
      t.boolean :allowed # when true, the step should be allowed by the rule AFTER match. otherwise, it is necessary for match and should be allowed BEFORE
    end

    add_foreign_key "portfolio_rule_steps", "portfolio_rules", column: "rule_id"
    add_foreign_key "portfolio_rule_steps", "portfolio_steps", column: "step_id"

    # each represents a condition and how to proceed in case of match.
    # A condition is applied to a portfolio item.
    create_table :portfolio_conditions do |t|
      t.belongs_to :rule
      t.text :matchers
      t.text :actions
      t.boolean :exit_portfolio
      t.integer :next_position # the position of ANOTHER portfolio rule. when match, the chain MUST be set to this position.
    end

    add_foreign_key "portfolio_conditions", "portfolio_rules" , column: "rule_id"


    #habtm table for portfolio_conditions. A condition CAN match when an item has a matching portfolio_step
    create_table :portfolio_conditions_steps do |t|
      t.belongs_to :condition
      t.belongs_to :step
    end

    add_foreign_key "portfolio_conditions_steps", "portfolio_conditions", column: "condition_id"
    add_foreign_key "portfolio_conditions_steps", "portfolio_steps", column: "step_id"

    #habtm table for portfolio_conditions. A condition CAN match when an item has a matching step_result
    create_table :portfolio_conditions_step_results do |t|
      t.belongs_to :condition
      t.belongs_to :step_result
    end

    add_foreign_key "portfolio_conditions_step_results", "portfolio_conditions", column: "condition_id"
    add_foreign_key "portfolio_conditions_step_results", "portfolio_step_results", column: "step_result_id"

    #habtm table for portfolio_conditions. A condition CAN match when an item has a matching document
    create_table :portfolio_conditions_document_types do |t|
      t.belongs_to :condition
      t.belongs_to :document_type
    end

    create_table :portfolio_document_types do |t|
      t.string   :name
      t.datetime :created_at, null: false
    end

    add_foreign_key "portfolio_conditions_document_types", "portfolio_conditions", column: "condition_id"
    add_foreign_key "portfolio_conditions_document_types", "portfolio_document_types", column: "document_type_id"

    add_column :portfolio_items, :position, :integer
    add_index :portfolio_items, [:client_id, :position], :unique => true

  end
end
