class CreateClientDuplicateDetections < ActiveRecord::Migration
  def change

    # csb creates a record for every duplicate request from another vsb
    create_table :client_duplicate_detection_requests do |t|
      t.integer :client_duplicate_request_id, index: {name: 'idx_cddr_on_cdr_id'}, null: false # this is the original request id on the vsb that created the duplicate request
      t.string :vsb_id, index: {name: 'idx_cddr_on_v_id'}, null: false # this is the id of the vsb that created the duplicate request
      t.integer :client_duplicate_detection_query_id ,index: {name: 'idx_cddr_on_cddq_id'}, null: false # this is the query id at csb for this request
      t.date :bday, null: false # bday that must be checked on this system
      t.string :first_name, null: false # first_name that must be checked on this system
      t.string :last_name, null: false # last_name that must be checked on this system
      t.string :gender, null: false # gender that must be checked on this system
      t.integer :retry_count, default: 0 # tried to send back result to csb this number of times
      t.integer :result_code, default: 0 # current status of duplicate check
      t.integer :announced_duplicate_count, default: nil
      t.integer :announcement_result_code, default: 0 # current status of result announcement for duplicate check
      t.timestamps
    end

    # vsb writes the duplicates for a client_duplicate_detection_request here
    create_table :client_duplicate_detections do |t|
      t.belongs_to :client_duplicate_detection_request, index: {name: 'idx_cdd_on_cddr_id'}, foreign_key:true, null: false
      t.date :bday, null: false
      t.belongs_to :client, index: {name: 'idx_cdd_on_cl_id', unique: true}, foreign_key:true, null: true # not null if: duplicate from client table
      t.belongs_to :client_duplicate_request, index: {name: 'idx_cdd_on_cdr_id', unique: true}, foreign_key:true, null: true # not null if: duplicate is currently in the create queue
      t.string :duplicate_type, null: false
      t.string :first_name, null: false
      t.string :last_name, null: false
      t.string :gender, null: false
      t.string :institution_name, null: true
      t.string :client_group_name, null: true
      t.integer :retry_count, default: 0 # tried to send back result to csb this number of times
      t.integer :result_code, default: 0 # current status of duplicate check
      t.timestamps
    end
  end
end
