require 'test_helper'
require 'pp'
module PortfolioValidation
  module ItemValidation
    module Validators
      class EvaluationTest < ActiveSupport::TestCase

        setup do
          @matcher = Portfolio::EvaluationPresentValidator::Base.new
          @matcher_time_span = Portfolio::EvaluationPresentValidator::Base.new
          @matcher_time_span.time_span_days_min=1
          @matcher_time_span.time_span_days_max=2
        end


        test "matches item with Evaluation" do
          item = ::Portfolio::Item.new
          item.target_agreements.build
          item.target_agreements.last.build_evaluation
          assert @matcher.match?(item)==true
        end

        test "matches no item without Evaluation" do
          item = ::Portfolio::Item.new
          item.target_agreements.build
          assert @matcher.match?(item)==false
          assert @matcher.has_error == true
          assert @matcher.error_message.present?
          assert @matcher.error_proc.is_a? Proc
        end

        test "matches item with Evaluations all have end date in range" do
          item = ::Portfolio::Item.new({start: Date.new(2000,1,1)})
          item.target_agreements.build
          item.target_agreements.last.build_evaluation({end_date: Date.new(2000,1,2)})
          item.target_agreements.build
          item.target_agreements.last.build_evaluation({end_date: Date.new(2000,1,3)})
          assert @matcher_time_span.match?(item)==true
        end

        test "matches no item without Evaluations all have end date in range" do
          item = ::Portfolio::Item.new({start: Date.new(2000,1,1)})
          item.target_agreements.build
          item.target_agreements.last.build_evaluation({end_date: Date.new(2000,1,3)})
          item.target_agreements.build
          item.target_agreements.last.build_evaluation({end_date: Date.new(2000,1,4)})
          assert @matcher_time_span.match?(item)==false
          assert @matcher_time_span.has_error == true
          assert @matcher_time_span.error_message.present?
          assert @matcher_time_span.error_proc.is_a? Proc
        end

      end
    end
  end
end